# ユースケース仕様書

## 概要

本文書は、Flexifyのユースケースの詳細仕様を定義します。各ユースケースについて、要求仕様と実装仕様を明確化し、実装進捗とテスト状況を管理します。

## UC-01: モジュール定義

### 要求 UC-01-01: ユーザーがModuleクラスを継承して処理モジュールを定義する

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-01-01-01 | ユーザーはModuleクラスを継承してカスタムモジュールを作成できる | 完了 | 完了 |
| UC-01-01-02 | 継承したクラスでexecute()メソッドを実装し、sessionを引数として受け取る | 完了 | 完了 |
| UC-01-01-03 | execute()メソッドは更新されたsessionを戻り値として返す | 完了 | 完了 |
| UC-01-01-04 | get_param_info()クラスメソッドでパラメータ情報をList[ParamInfo]として定義する | 完了 | 完了 |
| UC-01-01-05 | モジュールはstatus属性を持ち、実行状況に応じて更新する | 完了 | 完了 |

### 要求 UC-01-02: パラメータ情報の定義と検証

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-01-02-01 | ParamInfoクラスでパラメータ名、型、必須フラグ、デフォルト値を定義 | 完了 | 完了 |
| UC-01-02-02 | 必須パラメータが不足している場合はFlexifyExceptionを発生 | 完了 | 完了 |
| UC-01-02-03 | 型が一致しない場合は適切な変換を試行し、失敗時はFlexifyExceptionを発生 | 完了 | 完了 |
| UC-01-02-04 | オプションパラメータの場合はデフォルト値を使用 | 完了 | 完了 |

## UC-02: ワークフロー定義

### 要求 UC-02-01: YAML形式でワークフローを定義する

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-02-01-01 | YAMLファイルでワークフロー名、バージョンを指定 | 完了 | 完了 |
| UC-02-01-02 | modules配列でモジュールの実行順序を定義 | 完了 | 完了 |
| UC-02-01-03 | 各モジュールにname、class_name、paramsを指定 | 完了 | 完了 |
| UC-02-01-04 | inputsとoutputsでモジュール間のデータマッピングを定義 | 完了 | 完了 |
| UC-02-01-05 | initial_sessionで初期データを設定 | 完了 | 完了 |

### 要求 UC-02-02: JSON形式でワークフローを定義する

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-02-02-01 | JSONファイルでYAMLと同等の構造を定義 | 完了 | 完了 |
| UC-02-02-02 | YAML、JSON両形式で同じワークフローを表現可能 | 完了 | 完了 |

## UC-03: ワークフロー実行

### 要求 UC-03-01: SimpleRunnerでワークフローを実行する

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-03-01-01 | ファイルパスを指定してワークフローを実行 | 完了 | 完了 |
| UC-03-01-02 | WorkflowConfigオブジェクトから直接実行 | 完了 | 完了 |
| UC-03-01-03 | モジュールを順番に実行し、sessionを引き継ぐ | 完了 | 完了 |
| UC-03-01-04 | 実行結果として最終sessionを返す | 完了 | 完了 |
| UC-03-01-05 | エラー発生時は適切な例外を発生し、実行を停止 | 完了 | 完了 |

### 要求 UC-03-02: モジュール間データフロー

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-03-02-01 | inputsマッピングで前のモジュールの出力を取得 | 完了 | 完了 |
| UC-03-02-02 | outputsマッピングで後続モジュールにデータを提供 | 完了 | 完了 |
| UC-03-02-03 | マッピングが未定義の場合は全sessionデータを引き継ぎ | 完了 | 完了 |

## UC-04: 進捗状況確認

### 要求 UC-04-01: 実行状況の監視

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-04-01-01 | get_status()でRunnerStatusオブジェクトを取得 | 完了 | 完了 |
| UC-04-01-02 | 現在実行中のモジュール名を確認 | 完了 | 完了 |
| UC-04-01-03 | 完了済みモジュールの一覧を確認 | 完了 | 完了 |
| UC-04-01-04 | 各モジュールの実行状態（PENDING、RUNNING、SUCCESS、FAILED）を確認 | 完了 | 完了 |
| UC-04-01-05 | 開始時刻と終了時刻を記録・取得 | 完了 | 完了 |

## UC-05: パラメータ検証

### 要求 UC-05-01: 自動パラメータ検証

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-05-01-01 | モジュール実行前にvalidate_inputs()で入力を検証 | 完了 | 完了 |
| UC-05-01-02 | ParamInfo.validate_value()で個別パラメータを検証 | 完了 | 完了 |
| UC-05-01-03 | 数値型の自動変換（int↔float）をサポート | 完了 | 完了 |
| UC-05-01-04 | 辞書型のパラメータを適切に検証 | 完了 | 完了 |

## UC-06: エラーハンドリング

### 要求 UC-06-01: 例外処理とエラー報告

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-06-01-01 | FlexifyExceptionで適切なエラーメッセージを提供 | 完了 | 完了 |
| UC-06-01-02 | パラメータ検証エラーでは不足・不正なパラメータ名を明示 | 完了 | 完了 |
| UC-06-01-03 | モジュール実行エラーでは失敗したモジュール名を明示 | 完了 | 完了 |
| UC-06-01-04 | ファイル読み込みエラーでは適切なFileNotFoundErrorを発生 | 完了 | 完了 |

## UC-07: セッション管理

### 要求 UC-07-01: データ共有メカニズム

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-07-01-01 | sessionを辞書型Dict[str, Any]として実装 | 完了 | 完了 |
| UC-07-01-02 | モジュール間でsessionデータを自動的に引き継ぎ | 完了 | 完了 |
| UC-07-01-03 | initial_sessionで初期データを設定 | 完了 | 完了 |
| UC-07-01-04 | 各モジュールが自由にsessionを読み書き可能 | 完了 | 完了 |

## UC-08: モジュール検索

### 要求 UC-08-01: 動的モジュール検出

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-08-01-01 | ModuleRegistryでパッケージ内のModuleサブクラスを自動検出 | 完了 | 完了 |
| UC-08-01-02 | discover_modules()で利用可能なモジュール一覧を取得 | 完了 | 完了 |
| UC-08-01-03 | クラス名からモジュールクラスを動的に取得 | 完了 | 完了 |
| UC-08-01-04 | 存在しないモジュール指定時は適切なエラーを発生 | 完了 | 完了 |

## UC-09: 将来機能 - Web API実行

### 要求 UC-09-01: HTTP経由でのワークフロー実行

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-09-01-01 | POST /workflows/runでワークフローファイルを受信・実行 | 未実装 | 未テスト |
| UC-09-01-02 | GET /workflows/{id}/statusで実行状況を確認 | 未実装 | 未テスト |
| UC-09-01-03 | WebSocket経由でリアルタイム進捗通知 | 未実装 | 未テスト |
| UC-09-01-04 | REST APIでワークフロー一覧・履歴管理 | 未実装 | 未テスト |

## UC-10: 将来機能 - 分散実行

### 要求 UC-10-01: 既存ワークフローエンジンとの連携

| 仕様番号 | 仕様 | 実装完了 | テスト完了 |
|---|---|---|---|
| UC-10-01-01 | PrefectRunnerでPrefectワークフローとして実行 | 未実装 | 未テスト |
| UC-10-01-02 | AirflowRunnerでAirflow DAGとして実行 | 未実装 | 未テスト |
| UC-10-01-03 | 分散環境での並列モジュール実行 | 未実装 | 未テスト |
| UC-10-01-04 | スケジューリングとリトライ機能 | 未実装 | 未テスト |

## 実装・テスト状況サマリー

### 完了済み機能
- **モジュール定義**: Moduleクラスの継承、パラメータ定義・検証
- **ワークフロー定義**: YAML/JSON形式でのワークフロー記述
- **ワークフロー実行**: SimpleRunnerによる順次実行
- **進捗状況確認**: RunnerStatusによるリアルタイム監視
- **パラメータ検証**: 型チェック、必須チェック、自動変換
- **エラーハンドリング**: 適切な例外処理とメッセージ
- **セッション管理**: モジュール間でのデータ共有
- **モジュール検索**: 動的なモジュール検出・登録

### 将来実装予定
- **Web API機能**: FastAPIを使用したHTTP API
- **分散実行機能**: Prefect/Airflow連携

### テストカバレッジ
現在のテストカバレッジは97%で、すべてのコア機能が十分にテストされています。